---
title: Baygon
hide:
  - navigation
  - toc
---
<section class="hero">
  <div class="hero__card">
      <img src="baygon.svg" alt="Baygon logo"/>
    <h1 class="hero__title">Baygon</h1>
    <p class="hero__subtitle">Minimalistic functional test framework</p>
    <div class="hero__actions">
      <a class="md-button md-button--primary" href="getting-started/">Getting Started</a>
      <a class="md-button" href="syntax/">Explore the syntax</a>
    </div>
  </div>
</section>
